import selectn from 'selectn';
import arrayManager from '../../../utils/arrayManager';
import { DOT_SERVICE_EVENT_TYPE_SHOW_TOAST_NOTIFICATION, DOT_SERVICE_EVENT_TYPE_HIDE_TOAST_NOTIFICATION, DOT_SERVICE_EVENT_TYPE_CLEAR_ALL_TOAST_NOTIFICATION, DOT_SERVICE_EVENT_TYPE_SHOW_PROMISE_TOAST_NOTIFICATION, DOT_SERVICE_EVENT_TYPE_UPDATE_PROMISE_TOAST_NOTIFICATION, DOT_SERVICE_EVENT_TYPE_HIDE_PROMISE_TOAST_NOTIFICATION } from '../../../service/helpers/constant';
import { DUMMY_ARRAY } from '../../../utils/constants';
const {
  addItem: _showToastNotification,
  removeItemById: _hideToastNotification,
  clearItems: _clearToastNotifications,
  updateItemById: _updateToastNotifications,
  getArray: _getToastNotifications
} = arrayManager();

function modifyPayload(payload) {
  const modifiedPayload = { ...payload
  };
  const id = selectn('id', modifiedPayload);
  delete modifiedPayload.id;
  return {
    id,
    data: modifiedPayload
  };
}

function getPayload(payload) {
  return modifyPayload(payload);
}

const toastNotificationReducer = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : DUMMY_ARRAY;
  let action = arguments.length > 1 ? arguments[1] : undefined;
  const {
    type,
    payload
  } = action;

  switch (type) {
    case DOT_SERVICE_EVENT_TYPE_SHOW_TOAST_NOTIFICATION:
      {
        const modifiedPayload = getPayload(payload);

        _showToastNotification(modifiedPayload);

        return _getToastNotifications();
      }

    case DOT_SERVICE_EVENT_TYPE_HIDE_TOAST_NOTIFICATION:
      {
        const id = selectn('id', payload);

        _hideToastNotification(id);

        return _getToastNotifications();
      }

    case DOT_SERVICE_EVENT_TYPE_CLEAR_ALL_TOAST_NOTIFICATION:
      {
        _clearToastNotifications();

        return _getToastNotifications();
      }

    case DOT_SERVICE_EVENT_TYPE_SHOW_PROMISE_TOAST_NOTIFICATION:
      {
        const {
          id,
          data
        } = getPayload(payload);

        _showToastNotification({
          id,
          data: { ...data,
            canAutoClose: false
          }
        });

        return _getToastNotifications();
      }

    case DOT_SERVICE_EVENT_TYPE_UPDATE_PROMISE_TOAST_NOTIFICATION:
      {
        const {
          id,
          data
        } = getPayload(payload);

        _updateToastNotifications(id, {
          data
        });

        return _getToastNotifications();
      }

    case DOT_SERVICE_EVENT_TYPE_HIDE_PROMISE_TOAST_NOTIFICATION:
      {
        const id = selectn('id', payload);

        _hideToastNotification(id);

        return _getToastNotifications();
      }

    default:
      console.error('No such service found in DOT Toast Notification Service');
      return state;
  }
};

export default toastNotificationReducer;