import { deleteFromArrayOfObjectById, appendToArray, modifyArrayOfObjectItemById, modifyArrayItemByItem, deleteFromArrayByItem, emptyArray } from '../arrayCRUD';
import { DUMMY_ARRAY } from '../constants';

function dummyFunc(arg) {
  return arg || null;
} // filepath: /Users/mari-19987/React_Package_02/jsapps/dot/dotkit/src/utils/arrayCRUD.test.js


describe('deleteFromArrayOfObjectById', () => {
  test('should delete an item by a valid id', () => {
    const arrayOfObject = [{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, {
      id: 2,
      name: 'Item 2',
      action: dummyFunc('2')
    }, {
      id: 3,
      name: 'Item 3',
      action: dummyFunc('3')
    }];
    const id = 2;
    const result = deleteFromArrayOfObjectById({
      arrayOfObject,
      id
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, {
      id: 3,
      name: 'Item 3',
      action: dummyFunc('3')
    }]);
  });
  test('should return the same array if id does not exist', () => {
    const arrayOfObject = [{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2'
    }];
    const id = 3;
    const result = deleteFromArrayOfObjectById({
      arrayOfObject,
      id
    });
    expect(result).toEqual(arrayOfObject);
  });
  test('should return the same array if id is undefined', () => {
    const arrayOfObject = [{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2'
    }];
    const id = undefined;
    const result = deleteFromArrayOfObjectById({
      arrayOfObject,
      id
    });
    expect(result).toEqual(arrayOfObject);
  });
  test('should return an empty array if the input array is empty', () => {
    const arrayOfObject = DUMMY_ARRAY;
    const id = 1;
    const result = deleteFromArrayOfObjectById({
      arrayOfObject,
      id
    });
    expect(result).toEqual(DUMMY_ARRAY);
  });
  test('should delete only the first occurrence of an item with a duplicate id', () => {
    const arrayOfObject = [{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2'
    }, {
      id: 2,
      name: 'Duplicate Item 2'
    }];
    const id = 2;
    const result = deleteFromArrayOfObjectById({
      arrayOfObject,
      id
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Duplicate Item 2'
    }]);
  });
});
describe('deleteFromArrayByItem', () => {
  test('should delete an item by matching the current item (primitive value)', () => {
    const array = [1, 2, 3, dummyFunc];
    const currentItem = 2;
    const result = deleteFromArrayByItem({
      array,
      currentItem
    });
    expect(result).toEqual([1, 3, dummyFunc]);
  });
  test('should return the same array if currentItem does not exist (primitive value)', () => {
    const array = [1, 2, 3];
    const currentItem = 4;
    const result = deleteFromArrayByItem({
      array,
      currentItem
    });
    expect(result).toEqual(array);
  });
  test('should delete an item by matching the current item (object)', () => {
    const array = [{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, {
      id: 2,
      name: 'Item 2',
      action: dummyFunc('2')
    }];
    const currentItem = {
      id: 2,
      name: 'Item 2',
      action: dummyFunc('2')
    };
    const result = deleteFromArrayByItem({
      array,
      currentItem
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }]);
  });
  test('should return the same array if currentItem does not exist (object)', () => {
    const array = [{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2'
    }];
    const currentItem = {
      id: 3,
      name: 'Item 3'
    };
    const result = deleteFromArrayByItem({
      array,
      currentItem
    });
    expect(result).toEqual(array);
  });
  test('should delete an item by matching the current item (array)', () => {
    const array = [[1, 2], [3, 4], [5, 6]];
    const currentItem = [3, 4];
    const result = deleteFromArrayByItem({
      array,
      currentItem
    });
    expect(result).toEqual([[1, 2], [5, 6]]);
  });
  test('should return the same array if currentItem does not exist (array)', () => {
    const array = [[1, 2], [3, 4], [5, 6]];
    const currentItem = [7, 8];
    const result = deleteFromArrayByItem({
      array,
      currentItem
    });
    expect(result).toEqual(array);
  });
  test('should delete only the first occurrence of the current item (primitive value)', () => {
    const array = [1, 2, 3, 2];
    const currentItem = 2;
    const result = deleteFromArrayByItem({
      array,
      currentItem
    });
    expect(result).toEqual([1, 3, 2]);
  });
  test('should delete only the first occurrence of the current item (object)', () => {
    const array = [{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2'
    }, {
      id: 2,
      name: 'Duplicate Item 2'
    }];
    const currentItem = {
      id: 2,
      name: 'Item 2'
    };
    const result = deleteFromArrayByItem({
      array,
      currentItem
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Duplicate Item 2'
    }]);
  });
  test('should delete only the first occurrence of the current item (array)', () => {
    const array = [[1, 2], [3, 4], [1, 2]];
    const currentItem = [1, 2];
    const result = deleteFromArrayByItem({
      array,
      currentItem
    });
    expect(result).toEqual([[3, 4], [1, 2]]);
  });
});
describe('appendToArray', () => {
  test('should append an item to the array', () => {
    const array = [1, 2, 3, dummyFunc];
    const item = 4;
    const result = appendToArray({
      array,
      item
    });
    expect(result).toEqual([1, 2, 3, dummyFunc, 4]);
  });
  test('should append an object to the array', () => {
    const array = [{
      id: 1,
      name: 'Item 1'
    }];
    const item = {
      id: 2,
      name: 'Item 2',
      dummyFunc
    };
    const result = appendToArray({
      array,
      item
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2',
      dummyFunc
    }]);
  });
});
describe('modifyArrayOfObjectItemById', () => {
  test('should modify an object as object by id', () => {
    const arrayOfObject = [{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, {
      id: 2,
      name: 'Item 2',
      action: dummyFunc('2')
    }];
    const id = 2;
    const newItem = {
      name: 'Updated Item 2',
      action: dummyFunc('3')
    };
    const result = modifyArrayOfObjectItemById({
      arrayOfObject,
      id,
      newItem
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, {
      id: 2,
      name: 'Updated Item 2',
      action: dummyFunc('3')
    }]);
  });
  test('should modify an object as array by id', () => {
    const arrayOfObject = [{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, {
      id: 2,
      name: 'Item 2',
      action: dummyFunc('2')
    }, {
      id: 3,
      name: 'Item 3',
      action: dummyFunc('3')
    }];
    const id = 2;
    const newItem = ['newItem1', 'newItem2'];
    const result = modifyArrayOfObjectItemById({
      arrayOfObject,
      id,
      newItem
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, ['newItem1', 'newItem2'], {
      id: 3,
      name: 'Item 3',
      action: dummyFunc('3')
    }]);
  });
  test('should modify an object as string by id', () => {
    const arrayOfObject = [{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, {
      id: 2,
      name: 'Item 2',
      action: dummyFunc('2')
    }, {
      id: 3,
      name: 'Item 3',
      action: dummyFunc('3')
    }];
    const id = 2;
    const newItem = 'newItem1';
    const result = modifyArrayOfObjectItemById({
      arrayOfObject,
      id,
      newItem
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, 'newItem1', {
      id: 3,
      name: 'Item 3',
      action: dummyFunc('3')
    }]);
  });
  test('should return the same array if id does not exist', () => {
    const arrayOfObject = [{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2'
    }];
    const id = 3;
    const newItem = {
      name: 'Updated Item 3'
    };
    const result = modifyArrayOfObjectItemById({
      arrayOfObject,
      id,
      newItem
    });
    expect(result).toEqual(arrayOfObject);
  });
  test('should modify only the first occurrence of an item with a duplicate id', () => {
    const arrayOfObject = [{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2'
    }, {
      id: 2,
      name: 'Duplicate Item 2'
    }];
    const id = 2;
    const newItem = {
      name: 'Updated Item 2'
    };
    const result = modifyArrayOfObjectItemById({
      arrayOfObject,
      id,
      newItem
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Updated Item 2'
    }, {
      id: 2,
      name: 'Duplicate Item 2'
    }]);
  });
  test('should return the same array if id is undefined', () => {
    const arrayOfObject = [{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2'
    }];
    const id = undefined;
    const newItem = {
      name: 'Updated Item 2'
    };
    const result = modifyArrayOfObjectItemById({
      arrayOfObject,
      id,
      newItem
    });
    expect(result).toEqual(arrayOfObject);
  });
});
describe('modifyArrayItemByItem', () => {
  test('should modify an item by matching the current item (primitive value)', () => {
    const array = [1, 2, 3];
    const currentItem = 2;
    const newItem = 4;
    const result = modifyArrayItemByItem({
      array,
      currentItem,
      newItem
    });
    expect(result).toEqual([1, 4, 3]);
  });
  test('should return the same array if currentItem does not exist (primitive value)', () => {
    const array = [1, 2, 3];
    const currentItem = 4;
    const newItem = 5;
    const result = modifyArrayItemByItem({
      array,
      currentItem,
      newItem
    });
    expect(result).toEqual(array);
  });
  test('should modify an item by matching the current item (object)', () => {
    const array = [{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, {
      id: 2,
      name: 'Item 2',
      action: dummyFunc('2')
    }];
    const currentItem = {
      id: 2,
      name: 'Item 2',
      action: dummyFunc('2')
    };
    const newItem = {
      id: 2,
      name: 'Updated Item 2',
      action: dummyFunc('3')
    };
    const result = modifyArrayItemByItem({
      array,
      currentItem,
      newItem
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, {
      id: 2,
      name: 'Updated Item 2',
      action: dummyFunc('3')
    }]);
  });
  test('should return the same array if currentItem does not exist (object)', () => {
    const array = [{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2'
    }];
    const currentItem = {
      id: 3,
      name: 'Item 3'
    };
    const newItem = {
      id: 3,
      name: 'Updated Item 3'
    };
    const result = modifyArrayItemByItem({
      array,
      currentItem,
      newItem
    });
    expect(result).toEqual(array);
  });
  test('should modify an item by matching the current item (array)', () => {
    const array = [[1, 2], [3, 4], [5, 6]];
    const currentItem = [3, 4];
    const newItem = [7, 8];
    const result = modifyArrayItemByItem({
      array,
      currentItem,
      newItem
    });
    expect(result).toEqual([[1, 2], [7, 8], [5, 6]]);
  });
  test('should return the same array if currentItem does not exist (array)', () => {
    const array = [[1, 2], [3, 4], [5, 6]];
    const currentItem = [7, 8];
    const newItem = [9, 10];
    const result = modifyArrayItemByItem({
      array,
      currentItem,
      newItem
    });
    expect(result).toEqual(array);
  });
  test('should modify only the first occurrence of the current item (primitive value)', () => {
    const array = [1, 2, 3, 2];
    const currentItem = 2;
    const newItem = 4;
    const result = modifyArrayItemByItem({
      array,
      currentItem,
      newItem
    });
    expect(result).toEqual([1, 4, 3, 2]);
  });
  test('should modify only the first occurrence of the current item (object)', () => {
    const array = [{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2'
    }, {
      id: 2,
      name: 'Duplicate Item 2'
    }];
    const currentItem = {
      id: 2,
      name: 'Item 2'
    };
    const newItem = {
      id: 2,
      name: 'Updated Item 2'
    };
    const result = modifyArrayItemByItem({
      array,
      currentItem,
      newItem
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Updated Item 2'
    }, {
      id: 2,
      name: 'Duplicate Item 2'
    }]);
  });
  test('should modify only the first occurrence of the current item (array)', () => {
    const array = [[1, 2], [3, 4], [1, 2]];
    const currentItem = [1, 2];
    const newItem = [7, 8];
    const result = modifyArrayItemByItem({
      array,
      currentItem,
      newItem
    });
    expect(result).toEqual([[7, 8], [3, 4], [1, 2]]);
  });
});
describe('emptyArray', () => {
  test('should return an empty array', () => {
    const result = emptyArray();
    expect(result).toEqual(DUMMY_ARRAY);
  });
});