import { deepEqual } from '../deepEqual'; // Filename: jsapps/dot/dotkit/src/utils/deepEqual.test.js

describe('deepEqual', () => {
  test('should return true for identical primitive values', () => {
    expect(deepEqual(1, 1)).toBe(true);
    expect(deepEqual('test', 'test')).toBe(true);
    expect(deepEqual(true, true)).toBe(true);
  });
  test('should return false for different primitive values', () => {
    expect(deepEqual(1, 2)).toBe(false);
    expect(deepEqual('test', 'Test')).toBe(false);
    expect(deepEqual(true, false)).toBe(false);
  });
  test('should return true for identical objects', () => {
    const obj1 = {
      a: 1,
      b: {
        c: 2
      }
    };
    const obj2 = {
      a: 1,
      b: {
        c: 2
      }
    };
    expect(deepEqual(obj1, obj2)).toBe(true);
  });
  test('should return false for different objects', () => {
    const obj1 = {
      a: 1,
      b: {
        c: 2
      }
    };
    const obj2 = {
      a: 1,
      b: {
        c: 3
      }
    };
    expect(deepEqual(obj1, obj2)).toBe(false);
  });
  test('should return true for identical arrays', () => {
    const arr1 = [1, 2, 3];
    const arr2 = [1, 2, 3];
    expect(deepEqual(arr1, arr2)).toBe(true);
  });
  test('should return false for different arrays', () => {
    const arr1 = [1, 2, 3];
    const arr2 = [1, 2, 4];
    expect(deepEqual(arr1, arr2)).toBe(false);
  }); // test('should return true for identical functions', () => {
  //     const func1 = function () { return 1; };
  //     const func2 = function () { return 1; };
  //     expect(deepEqual(func1, func2)).toBe(true);
  // });

  test('should return false for different functions', () => {
    const func1 = function () {
      return 1;
    };

    const func2 = function () {
      return 2;
    };

    expect(deepEqual(func1, func2)).toBe(false);
  });
  test('should return true for null values', () => {
    expect(deepEqual(null, null)).toBe(true);
  });
  test('should return false for null and non-null values', () => {
    expect(deepEqual(null, {})).toBe(false);
    expect(deepEqual({}, null)).toBe(false);
  });
  test('should return false for different types', () => {
    expect(deepEqual(1, '1')).toBe(false);
    expect(deepEqual([], {})).toBe(false);
    expect(deepEqual(true, 1)).toBe(false);
  });
});