export const dispatchCustomEvent = _ref => {
  let {
    eventName,
    detail,
    dispatchElement
  } = _ref;
  // 'bubbles: true' allows the event to propagate up through the DOM
  // This enables child-to-parent communication by listening to the event on the parent
  const event = new CustomEvent(eventName, {
    bubbles: true,
    detail
  });

  if (dispatchElement && !(dispatchElement instanceof EventTarget)) {
    console.warn(`'dispatchElement' is not a valid EventTarget. Falling back to 'window'.`);
    dispatchElement = null;
  }

  (dispatchElement || window).dispatchEvent(event);
};
export const addCustomEventListener = _ref2 => {
  let {
    eventName,
    callback,
    dispatchElement
  } = _ref2;
  const target = dispatchElement instanceof EventTarget ? dispatchElement : window;
  target.addEventListener(eventName, callback);
};
export const removeCustomEventListener = _ref3 => {
  let {
    eventName,
    callback,
    dispatchElement
  } = _ref3;
  const target = dispatchElement instanceof EventTarget ? dispatchElement : window;
  target.removeEventListener(eventName, callback);
};