"use strict";

var _arrayCRUD = require("../arrayCRUD");

var _constants = require("../constants");

function dummyFunc(arg) {
  return arg || null;
} // filepath: /Users/mari-19987/React_Package_02/jsapps/dot/dotkit/src/utils/arrayCRUD.test.js


describe('deleteFromArrayOfObjectById', function () {
  test('should delete an item by a valid id', function () {
    var arrayOfObject = [{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, {
      id: 2,
      name: 'Item 2',
      action: dummyFunc('2')
    }, {
      id: 3,
      name: 'Item 3',
      action: dummyFunc('3')
    }];
    var id = 2;
    var result = (0, _arrayCRUD.deleteFromArrayOfObjectById)({
      arrayOfObject: arrayOfObject,
      id: id
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, {
      id: 3,
      name: 'Item 3',
      action: dummyFunc('3')
    }]);
  });
  test('should return the same array if id does not exist', function () {
    var arrayOfObject = [{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2'
    }];
    var id = 3;
    var result = (0, _arrayCRUD.deleteFromArrayOfObjectById)({
      arrayOfObject: arrayOfObject,
      id: id
    });
    expect(result).toEqual(arrayOfObject);
  });
  test('should return the same array if id is undefined', function () {
    var arrayOfObject = [{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2'
    }];
    var id = undefined;
    var result = (0, _arrayCRUD.deleteFromArrayOfObjectById)({
      arrayOfObject: arrayOfObject,
      id: id
    });
    expect(result).toEqual(arrayOfObject);
  });
  test('should return an empty array if the input array is empty', function () {
    var arrayOfObject = _constants.DUMMY_ARRAY;
    var id = 1;
    var result = (0, _arrayCRUD.deleteFromArrayOfObjectById)({
      arrayOfObject: arrayOfObject,
      id: id
    });
    expect(result).toEqual(_constants.DUMMY_ARRAY);
  });
  test('should delete only the first occurrence of an item with a duplicate id', function () {
    var arrayOfObject = [{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2'
    }, {
      id: 2,
      name: 'Duplicate Item 2'
    }];
    var id = 2;
    var result = (0, _arrayCRUD.deleteFromArrayOfObjectById)({
      arrayOfObject: arrayOfObject,
      id: id
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Duplicate Item 2'
    }]);
  });
});
describe('deleteFromArrayByItem', function () {
  test('should delete an item by matching the current item (primitive value)', function () {
    var array = [1, 2, 3, dummyFunc];
    var currentItem = 2;
    var result = (0, _arrayCRUD.deleteFromArrayByItem)({
      array: array,
      currentItem: currentItem
    });
    expect(result).toEqual([1, 3, dummyFunc]);
  });
  test('should return the same array if currentItem does not exist (primitive value)', function () {
    var array = [1, 2, 3];
    var currentItem = 4;
    var result = (0, _arrayCRUD.deleteFromArrayByItem)({
      array: array,
      currentItem: currentItem
    });
    expect(result).toEqual(array);
  });
  test('should delete an item by matching the current item (object)', function () {
    var array = [{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, {
      id: 2,
      name: 'Item 2',
      action: dummyFunc('2')
    }];
    var currentItem = {
      id: 2,
      name: 'Item 2',
      action: dummyFunc('2')
    };
    var result = (0, _arrayCRUD.deleteFromArrayByItem)({
      array: array,
      currentItem: currentItem
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }]);
  });
  test('should return the same array if currentItem does not exist (object)', function () {
    var array = [{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2'
    }];
    var currentItem = {
      id: 3,
      name: 'Item 3'
    };
    var result = (0, _arrayCRUD.deleteFromArrayByItem)({
      array: array,
      currentItem: currentItem
    });
    expect(result).toEqual(array);
  });
  test('should delete an item by matching the current item (array)', function () {
    var array = [[1, 2], [3, 4], [5, 6]];
    var currentItem = [3, 4];
    var result = (0, _arrayCRUD.deleteFromArrayByItem)({
      array: array,
      currentItem: currentItem
    });
    expect(result).toEqual([[1, 2], [5, 6]]);
  });
  test('should return the same array if currentItem does not exist (array)', function () {
    var array = [[1, 2], [3, 4], [5, 6]];
    var currentItem = [7, 8];
    var result = (0, _arrayCRUD.deleteFromArrayByItem)({
      array: array,
      currentItem: currentItem
    });
    expect(result).toEqual(array);
  });
  test('should delete only the first occurrence of the current item (primitive value)', function () {
    var array = [1, 2, 3, 2];
    var currentItem = 2;
    var result = (0, _arrayCRUD.deleteFromArrayByItem)({
      array: array,
      currentItem: currentItem
    });
    expect(result).toEqual([1, 3, 2]);
  });
  test('should delete only the first occurrence of the current item (object)', function () {
    var array = [{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2'
    }, {
      id: 2,
      name: 'Duplicate Item 2'
    }];
    var currentItem = {
      id: 2,
      name: 'Item 2'
    };
    var result = (0, _arrayCRUD.deleteFromArrayByItem)({
      array: array,
      currentItem: currentItem
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Duplicate Item 2'
    }]);
  });
  test('should delete only the first occurrence of the current item (array)', function () {
    var array = [[1, 2], [3, 4], [1, 2]];
    var currentItem = [1, 2];
    var result = (0, _arrayCRUD.deleteFromArrayByItem)({
      array: array,
      currentItem: currentItem
    });
    expect(result).toEqual([[3, 4], [1, 2]]);
  });
});
describe('appendToArray', function () {
  test('should append an item to the array', function () {
    var array = [1, 2, 3, dummyFunc];
    var item = 4;
    var result = (0, _arrayCRUD.appendToArray)({
      array: array,
      item: item
    });
    expect(result).toEqual([1, 2, 3, dummyFunc, 4]);
  });
  test('should append an object to the array', function () {
    var array = [{
      id: 1,
      name: 'Item 1'
    }];
    var item = {
      id: 2,
      name: 'Item 2',
      dummyFunc: dummyFunc
    };
    var result = (0, _arrayCRUD.appendToArray)({
      array: array,
      item: item
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2',
      dummyFunc: dummyFunc
    }]);
  });
});
describe('modifyArrayOfObjectItemById', function () {
  test('should modify an object as object by id', function () {
    var arrayOfObject = [{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, {
      id: 2,
      name: 'Item 2',
      action: dummyFunc('2')
    }];
    var id = 2;
    var newItem = {
      name: 'Updated Item 2',
      action: dummyFunc('3')
    };
    var result = (0, _arrayCRUD.modifyArrayOfObjectItemById)({
      arrayOfObject: arrayOfObject,
      id: id,
      newItem: newItem
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, {
      id: 2,
      name: 'Updated Item 2',
      action: dummyFunc('3')
    }]);
  });
  test('should modify an object as array by id', function () {
    var arrayOfObject = [{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, {
      id: 2,
      name: 'Item 2',
      action: dummyFunc('2')
    }, {
      id: 3,
      name: 'Item 3',
      action: dummyFunc('3')
    }];
    var id = 2;
    var newItem = ['newItem1', 'newItem2'];
    var result = (0, _arrayCRUD.modifyArrayOfObjectItemById)({
      arrayOfObject: arrayOfObject,
      id: id,
      newItem: newItem
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, ['newItem1', 'newItem2'], {
      id: 3,
      name: 'Item 3',
      action: dummyFunc('3')
    }]);
  });
  test('should modify an object as string by id', function () {
    var arrayOfObject = [{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, {
      id: 2,
      name: 'Item 2',
      action: dummyFunc('2')
    }, {
      id: 3,
      name: 'Item 3',
      action: dummyFunc('3')
    }];
    var id = 2;
    var newItem = 'newItem1';
    var result = (0, _arrayCRUD.modifyArrayOfObjectItemById)({
      arrayOfObject: arrayOfObject,
      id: id,
      newItem: newItem
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, 'newItem1', {
      id: 3,
      name: 'Item 3',
      action: dummyFunc('3')
    }]);
  });
  test('should return the same array if id does not exist', function () {
    var arrayOfObject = [{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2'
    }];
    var id = 3;
    var newItem = {
      name: 'Updated Item 3'
    };
    var result = (0, _arrayCRUD.modifyArrayOfObjectItemById)({
      arrayOfObject: arrayOfObject,
      id: id,
      newItem: newItem
    });
    expect(result).toEqual(arrayOfObject);
  });
  test('should modify only the first occurrence of an item with a duplicate id', function () {
    var arrayOfObject = [{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2'
    }, {
      id: 2,
      name: 'Duplicate Item 2'
    }];
    var id = 2;
    var newItem = {
      name: 'Updated Item 2'
    };
    var result = (0, _arrayCRUD.modifyArrayOfObjectItemById)({
      arrayOfObject: arrayOfObject,
      id: id,
      newItem: newItem
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Updated Item 2'
    }, {
      id: 2,
      name: 'Duplicate Item 2'
    }]);
  });
  test('should return the same array if id is undefined', function () {
    var arrayOfObject = [{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2'
    }];
    var id = undefined;
    var newItem = {
      name: 'Updated Item 2'
    };
    var result = (0, _arrayCRUD.modifyArrayOfObjectItemById)({
      arrayOfObject: arrayOfObject,
      id: id,
      newItem: newItem
    });
    expect(result).toEqual(arrayOfObject);
  });
});
describe('modifyArrayItemByItem', function () {
  test('should modify an item by matching the current item (primitive value)', function () {
    var array = [1, 2, 3];
    var currentItem = 2;
    var newItem = 4;
    var result = (0, _arrayCRUD.modifyArrayItemByItem)({
      array: array,
      currentItem: currentItem,
      newItem: newItem
    });
    expect(result).toEqual([1, 4, 3]);
  });
  test('should return the same array if currentItem does not exist (primitive value)', function () {
    var array = [1, 2, 3];
    var currentItem = 4;
    var newItem = 5;
    var result = (0, _arrayCRUD.modifyArrayItemByItem)({
      array: array,
      currentItem: currentItem,
      newItem: newItem
    });
    expect(result).toEqual(array);
  });
  test('should modify an item by matching the current item (object)', function () {
    var array = [{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, {
      id: 2,
      name: 'Item 2',
      action: dummyFunc('2')
    }];
    var currentItem = {
      id: 2,
      name: 'Item 2',
      action: dummyFunc('2')
    };
    var newItem = {
      id: 2,
      name: 'Updated Item 2',
      action: dummyFunc('3')
    };
    var result = (0, _arrayCRUD.modifyArrayItemByItem)({
      array: array,
      currentItem: currentItem,
      newItem: newItem
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1',
      action: dummyFunc('1')
    }, {
      id: 2,
      name: 'Updated Item 2',
      action: dummyFunc('3')
    }]);
  });
  test('should return the same array if currentItem does not exist (object)', function () {
    var array = [{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2'
    }];
    var currentItem = {
      id: 3,
      name: 'Item 3'
    };
    var newItem = {
      id: 3,
      name: 'Updated Item 3'
    };
    var result = (0, _arrayCRUD.modifyArrayItemByItem)({
      array: array,
      currentItem: currentItem,
      newItem: newItem
    });
    expect(result).toEqual(array);
  });
  test('should modify an item by matching the current item (array)', function () {
    var array = [[1, 2], [3, 4], [5, 6]];
    var currentItem = [3, 4];
    var newItem = [7, 8];
    var result = (0, _arrayCRUD.modifyArrayItemByItem)({
      array: array,
      currentItem: currentItem,
      newItem: newItem
    });
    expect(result).toEqual([[1, 2], [7, 8], [5, 6]]);
  });
  test('should return the same array if currentItem does not exist (array)', function () {
    var array = [[1, 2], [3, 4], [5, 6]];
    var currentItem = [7, 8];
    var newItem = [9, 10];
    var result = (0, _arrayCRUD.modifyArrayItemByItem)({
      array: array,
      currentItem: currentItem,
      newItem: newItem
    });
    expect(result).toEqual(array);
  });
  test('should modify only the first occurrence of the current item (primitive value)', function () {
    var array = [1, 2, 3, 2];
    var currentItem = 2;
    var newItem = 4;
    var result = (0, _arrayCRUD.modifyArrayItemByItem)({
      array: array,
      currentItem: currentItem,
      newItem: newItem
    });
    expect(result).toEqual([1, 4, 3, 2]);
  });
  test('should modify only the first occurrence of the current item (object)', function () {
    var array = [{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Item 2'
    }, {
      id: 2,
      name: 'Duplicate Item 2'
    }];
    var currentItem = {
      id: 2,
      name: 'Item 2'
    };
    var newItem = {
      id: 2,
      name: 'Updated Item 2'
    };
    var result = (0, _arrayCRUD.modifyArrayItemByItem)({
      array: array,
      currentItem: currentItem,
      newItem: newItem
    });
    expect(result).toEqual([{
      id: 1,
      name: 'Item 1'
    }, {
      id: 2,
      name: 'Updated Item 2'
    }, {
      id: 2,
      name: 'Duplicate Item 2'
    }]);
  });
  test('should modify only the first occurrence of the current item (array)', function () {
    var array = [[1, 2], [3, 4], [1, 2]];
    var currentItem = [1, 2];
    var newItem = [7, 8];
    var result = (0, _arrayCRUD.modifyArrayItemByItem)({
      array: array,
      currentItem: currentItem,
      newItem: newItem
    });
    expect(result).toEqual([[7, 8], [3, 4], [1, 2]]);
  });
});
describe('emptyArray', function () {
  test('should return an empty array', function () {
    var result = (0, _arrayCRUD.emptyArray)();
    expect(result).toEqual(_constants.DUMMY_ARRAY);
  });
});