"use strict";

var _deepEqual = require("../deepEqual");

// Filename: jsapps/dot/dotkit/src/utils/deepEqual.test.js
describe('deepEqual', function () {
  test('should return true for identical primitive values', function () {
    expect((0, _deepEqual.deepEqual)(1, 1)).toBe(true);
    expect((0, _deepEqual.deepEqual)('test', 'test')).toBe(true);
    expect((0, _deepEqual.deepEqual)(true, true)).toBe(true);
  });
  test('should return false for different primitive values', function () {
    expect((0, _deepEqual.deepEqual)(1, 2)).toBe(false);
    expect((0, _deepEqual.deepEqual)('test', 'Test')).toBe(false);
    expect((0, _deepEqual.deepEqual)(true, false)).toBe(false);
  });
  test('should return true for identical objects', function () {
    var obj1 = {
      a: 1,
      b: {
        c: 2
      }
    };
    var obj2 = {
      a: 1,
      b: {
        c: 2
      }
    };
    expect((0, _deepEqual.deepEqual)(obj1, obj2)).toBe(true);
  });
  test('should return false for different objects', function () {
    var obj1 = {
      a: 1,
      b: {
        c: 2
      }
    };
    var obj2 = {
      a: 1,
      b: {
        c: 3
      }
    };
    expect((0, _deepEqual.deepEqual)(obj1, obj2)).toBe(false);
  });
  test('should return true for identical arrays', function () {
    var arr1 = [1, 2, 3];
    var arr2 = [1, 2, 3];
    expect((0, _deepEqual.deepEqual)(arr1, arr2)).toBe(true);
  });
  test('should return false for different arrays', function () {
    var arr1 = [1, 2, 3];
    var arr2 = [1, 2, 4];
    expect((0, _deepEqual.deepEqual)(arr1, arr2)).toBe(false);
  }); // test('should return true for identical functions', () => {
  //     const func1 = function () { return 1; };
  //     const func2 = function () { return 1; };
  //     expect(deepEqual(func1, func2)).toBe(true);
  // });

  test('should return false for different functions', function () {
    var func1 = function func1() {
      return 1;
    };

    var func2 = function func2() {
      return 2;
    };

    expect((0, _deepEqual.deepEqual)(func1, func2)).toBe(false);
  });
  test('should return true for null values', function () {
    expect((0, _deepEqual.deepEqual)(null, null)).toBe(true);
  });
  test('should return false for null and non-null values', function () {
    expect((0, _deepEqual.deepEqual)(null, {})).toBe(false);
    expect((0, _deepEqual.deepEqual)({}, null)).toBe(false);
  });
  test('should return false for different types', function () {
    expect((0, _deepEqual.deepEqual)(1, '1')).toBe(false);
    expect((0, _deepEqual.deepEqual)([], {})).toBe(false);
    expect((0, _deepEqual.deepEqual)(true, 1)).toBe(false);
  });
});