"use strict";

var _constants = require("../constants");

var _objectCRUD = require("../objectCRUD");

// filepath: /Users/mari-19987/React_Package_02/jsapps/dot/dotkit/src/utils/objectCRUD.test.js
describe('mergeObjects', function () {
  test('merges two objects with no overlapping keys', function () {
    var object = {
      a: 1,
      b: 2
    };
    var newObject = {
      c: 3,
      d: 4
    };
    var result = (0, _objectCRUD.mergeObjects)({
      object: object,
      newObject: newObject
    });
    expect(result).toEqual({
      a: 1,
      b: 2,
      c: 3,
      d: 4
    });
  });
  test('merges two objects with overlapping keys (new object overwrites)', function () {
    var object = {
      a: 1,
      b: 2
    };
    var newObject = {
      b: 3,
      c: 4
    };
    var result = (0, _objectCRUD.mergeObjects)({
      object: object,
      newObject: newObject
    });
    expect(result).toEqual({
      a: 1,
      b: 3,
      c: 4
    });
  });
  test('merges an empty object with another object', function () {
    var object = _constants.DUMMY_OBJECT;
    var newObject = {
      a: 1,
      b: 2
    };
    var result = (0, _objectCRUD.mergeObjects)({
      object: object,
      newObject: newObject
    });
    expect(result).toEqual({
      a: 1,
      b: 2
    });
  });
  test('merges an object with undefined or null values', function () {
    var object = {
      a: 1,
      b: 2
    };
    var newObject = {
      b: null,
      c: undefined
    };
    var result = (0, _objectCRUD.mergeObjects)({
      object: object,
      newObject: newObject
    });
    expect(result).toEqual({
      a: 1,
      b: null,
      c: undefined
    });
  });
  test('merges objects with nested structures', function () {
    var object = {
      a: 1,
      b: {
        x: 10,
        y: 20
      }
    };
    var newObject = {
      b: {
        z: 30
      },
      c: 3
    };
    var result = (0, _objectCRUD.mergeObjects)({
      object: object,
      newObject: newObject
    });
    expect(result).toEqual({
      a: 1,
      b: {
        z: 30
      },
      c: 3
    });
  });
});
describe('emptyObject', function () {
  test('returns the DUMMY_OBJECT constant', function () {
    var result = (0, _objectCRUD.emptyObject)();
    expect(result).toEqual(_constants.DUMMY_OBJECT);
  });
});
describe('updateObjectValueByKey', function () {
  test('updates a specific key with a new value', function () {
    var object = {
      a: 1,
      b: 2
    };
    var result = (0, _objectCRUD.updateObjectValueByKey)({
      object: object,
      key: 'b',
      value: 3
    });
    expect(result).toEqual({
      a: 1,
      b: 3
    });
  });
  test('adds a new key if it does not exist', function () {
    var object = {
      a: 1
    };
    var result = (0, _objectCRUD.updateObjectValueByKey)({
      object: object,
      key: 'b',
      value: 2
    });
    expect(result).toEqual({
      a: 1,
      b: 2
    });
  });
});
describe('removeObjectByKeys', function () {
  test('removes specified keys from the object', function () {
    var object = {
      a: 1,
      b: 2,
      c: 3
    };
    var result = (0, _objectCRUD.removeObjectByKeys)({
      object: object,
      keys: ['b', 'c']
    });
    expect(result).toEqual({
      a: 1
    });
  });
  test('does nothing if keys array is empty', function () {
    var object = {
      a: 1,
      b: 2
    };
    var result = (0, _objectCRUD.removeObjectByKeys)({
      object: object,
      keys: []
    });
    expect(result).toEqual({
      a: 1,
      b: 2
    });
  });
  test('does nothing if keys do not exist in the object', function () {
    var object = {
      a: 1,
      b: 2
    };
    var result = (0, _objectCRUD.removeObjectByKeys)({
      object: object,
      keys: ['c', 'd']
    });
    expect(result).toEqual({
      a: 1,
      b: 2
    });
  });
});
describe('removeObjectByKey', function () {
  test('removes a specific key from the object', function () {
    var object = {
      a: 1,
      b: 2
    };
    var result = (0, _objectCRUD.removeObjectByKey)({
      object: object,
      key: 'b'
    });
    expect(result).toEqual({
      a: 1
    });
  });
  test('does nothing if the key does not exist', function () {
    var object = {
      a: 1,
      b: 2
    };
    var result = (0, _objectCRUD.removeObjectByKey)({
      object: object,
      key: 'c'
    });
    expect(result).toEqual({
      a: 1,
      b: 2
    });
  });
});