"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.removeCustomEventListener = exports.dispatchCustomEvent = exports.addCustomEventListener = void 0;

var dispatchCustomEvent = function dispatchCustomEvent(_ref) {
  var eventName = _ref.eventName,
      detail = _ref.detail,
      dispatchElement = _ref.dispatchElement;
  // 'bubbles: true' allows the event to propagate up through the DOM
  // This enables child-to-parent communication by listening to the event on the parent
  var event = new CustomEvent(eventName, {
    bubbles: true,
    detail: detail
  });

  if (dispatchElement && !(dispatchElement instanceof EventTarget)) {
    console.warn("'dispatchElement' is not a valid EventTarget. Falling back to 'window'.");
    dispatchElement = null;
  }

  (dispatchElement || window).dispatchEvent(event);
};

exports.dispatchCustomEvent = dispatchCustomEvent;

var addCustomEventListener = function addCustomEventListener(_ref2) {
  var eventName = _ref2.eventName,
      callback = _ref2.callback,
      dispatchElement = _ref2.dispatchElement;
  var target = dispatchElement instanceof EventTarget ? dispatchElement : window;
  target.addEventListener(eventName, callback);
};

exports.addCustomEventListener = addCustomEventListener;

var removeCustomEventListener = function removeCustomEventListener(_ref3) {
  var eventName = _ref3.eventName,
      callback = _ref3.callback,
      dispatchElement = _ref3.dispatchElement;
  var target = dispatchElement instanceof EventTarget ? dispatchElement : window;
  target.removeEventListener(eventName, callback);
};

exports.removeCustomEventListener = removeCustomEventListener;